From 54bbca1aa29e07045427571c7dce54f8e85f6dcd Mon Sep 17 00:00:00 2001
From: owenbush <ojb@ukhhf.co.uk>
Date: Thu, 2 Apr 2020 15:47:01 -0600
Subject: [PATCH] Removed references to deprecated entity.manager service

---
 .../src/Form/RegistrantForm.php                      | 12 ++++++------
 src/Form/EventInstanceDeleteForm.php                 | 12 ++++++------
 src/Form/EventInstanceForm.php                       | 12 ++++++------
 src/Form/EventSeriesDeleteForm.php                   | 12 ++++++------
 src/Form/EventSeriesForm.php                         |  6 +-----
 5 files changed, 25 insertions(+), 29 deletions(-)

diff --git a/src/Form/EventSeriesForm.php b/src/Form/EventSeriesForm.php
index 9dd74b2f..a7900541 100644
--- a/src/Form/EventSeriesForm.php
+++ b/src/Form/EventSeriesForm.php
@@ -5,7 +5,6 @@ namespace Drupal\recurring_events\Form;
 use Drupal\Core\Entity\ContentEntityForm;
 use Drupal\Core\Form\FormStateInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
 use Drupal\recurring_events\EventCreationService;
 use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\Core\Messenger\Messenger;
@@ -111,7 +110,6 @@ class EventSeriesForm extends ContentEntityForm {
     return new static(
       $container->get('recurring_events.event_creation_service'),
       $container->get('entity_type.manager')->getStorage('eventseries'),
-      $container->get('entity.manager'),
       $container->get('messenger'),
       $container->get('date.formatter'),
       $container->get('entity_field.manager'),
@@ -132,8 +130,6 @@ class EventSeriesForm extends ContentEntityForm {
    *   The event creation service.
    * @param \Drupal\Core\Entity\EntityStorageInterface $storage
    *   The storage interface.
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
    * @param \Drupal\Core\Datetime\DateFormatter $date_formatter
@@ -155,7 +151,7 @@ class EventSeriesForm extends ContentEntityForm {
    * @param \Drupal\Core\Config\ConfigFactory $config_factory
    *   The config factory.
    */
-  public function __construct(EventCreationService $creation_service, EntityStorageInterface $storage, EntityManagerInterface $entity_manager, Messenger $messenger, DateFormatter $date_formatter, EntityFieldManager $entity_field_manager, FieldTypePluginManager $field_type_plugin_manager, EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info = NULL, TimeInterface $time = NULL, AccountProxyInterface $current_user = NULL, ModuleHandler $module_handler = NULL, ConfigFactory $config_factory = NULL) {
+  public function __construct(EventCreationService $creation_service, EntityStorageInterface $storage, Messenger $messenger, DateFormatter $date_formatter, EntityFieldManager $entity_field_manager, FieldTypePluginManager $field_type_plugin_manager, EntityRepositoryInterface $entity_repository, EntityTypeBundleInfoInterface $entity_type_bundle_info = NULL, TimeInterface $time = NULL, AccountProxyInterface $current_user = NULL, ModuleHandler $module_handler = NULL, ConfigFactory $config_factory = NULL) {
     $this->creationService = $creation_service;
     $this->storage = $storage;
     $this->messenger = $messenger;
diff --git a/modules/recurring_events_registration/src/Form/RegistrantForm.php b/modules/recurring_events_registration/src/Form/RegistrantForm.php
index 958de7bf..73f277ce 100644
--- a/modules/recurring_events_registration/src/Form/RegistrantForm.php
+++ b/modules/recurring_events_registration/src/Form/RegistrantForm.php
@@ -5,7 +5,7 @@ namespace Drupal\recurring_events_registration\Form;
 use Drupal\Core\Entity\ContentEntityForm;
 use Drupal\Core\Form\FormStateInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Messenger\Messenger;
 use Drupal\recurring_events_registration\RegistrationCreationService;
 use Drupal\Core\Session\AccountProxyInterface;
@@ -75,7 +75,7 @@ class RegistrantForm extends ContentEntityForm {
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity.repository'),
       $container->get('messenger'),
       $container->get('recurring_events_registration.creation_service'),
       $container->get('current_user'),
@@ -89,8 +89,8 @@ class RegistrantForm extends ContentEntityForm {
   /**
    * Construct an RegistrantForm.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
    * @param \Drupal\recurring_events_registration\RegistrationCreationService $creation_service
@@ -107,7 +107,7 @@ class RegistrantForm extends ContentEntityForm {
    *   The entity type manager service.
    */
   public function __construct(
-    EntityManagerInterface $entity_manager,
+    EntityRepositoryInterface $entity_repository,
     Messenger $messenger,
     RegistrationCreationService $creation_service,
     AccountProxyInterface $current_user,
@@ -122,7 +122,7 @@ class RegistrantForm extends ContentEntityForm {
     $this->fieldManager = $field_manager;
     $this->routeMatch = $route_match;
     $this->entityTypeManager = $entity_type_manager;
-    parent::__construct($entity_manager);
+    parent::__construct($entity_repository);
   }
 
   /**
@@ -89,8 +89,8 @@ class RegistrantForm extends ContentEntityForm {
    * Construct an RegistrantForm.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
diff --git a/src/Form/EventInstanceDeleteForm.php b/src/Form/EventInstanceDeleteForm.php
index 9b53f750..20d500f4 100644
--- a/src/Form/EventInstanceDeleteForm.php
+++ b/src/Form/EventInstanceDeleteForm.php
@@ -5,7 +5,7 @@ namespace Drupal\recurring_events\Form;
 use Drupal\Core\Entity\ContentEntityDeleteForm;
 use Drupal\Core\Form\FormStateInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Url;
 use Drupal\Core\Messenger\Messenger;
 use Drupal\Core\Datetime\DateFormatter;
@@ -41,15 +41,15 @@ class EventInstanceDeleteForm extends ContentEntityDeleteForm {
   /**
    * Construct a EventInstanceDeleteForm.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
    * @param \Drupal\Core\Datetime\DateFormatter $date_formatter
    *   The date formatter service.
    */
-  public function __construct(EntityManagerInterface $entity_manager, Messenger $messenger, DateFormatter $date_formatter) {
-    parent::__construct($entity_manager);
+  public function __construct(EntityRepositoryInterface $entity_repository, Messenger $messenger, DateFormatter $date_formatter) {
+    parent::__construct($entity_repository);
     $this->messenger = $messenger;
     $this->dateFormatter = $date_formatter;
   }
@@ -59,7 +59,7 @@ class EventInstanceDeleteForm extends ContentEntityDeleteForm {
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity.repository'),
       $container->get('messenger'),
       $container->get('date.formatter')
     );
@@ -41,15 +41,15 @@ class EventInstanceDeleteForm extends ContentEntityDeleteForm {
    * Construct a EventInstanceDeleteForm.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
diff --git a/src/Form/EventInstanceForm.php b/src/Form/EventInstanceForm.php
index 97063871..f084247c 100644
--- a/src/Form/EventInstanceForm.php
+++ b/src/Form/EventInstanceForm.php
@@ -5,7 +5,7 @@ namespace Drupal\recurring_events\Form;
 use Drupal\Core\Entity\ContentEntityForm;
 use Drupal\Core\Form\FormStateInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Messenger\Messenger;
 use Drupal\Core\Session\AccountProxyInterface;
 use Drupal\Component\Datetime\TimeInterface;
@@ -43,7 +43,7 @@ class EventInstanceForm extends ContentEntityForm {
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity.repository'),
       $container->get('messenger'),
       $container->get('current_user'),
       $container->get('datetime.time')
@@ -53,8 +53,8 @@ class EventInstanceForm extends ContentEntityForm {
   /**
    * Construct an EventInstanceForm.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
    * @param \Drupal\Core\Session\AccountProxyInterface $current_user
@@ -62,11 +62,11 @@ class EventInstanceForm extends ContentEntityForm {
    * @param \Drupal\Component\Datetime\TimeInterface $time
    *   The time service.
    */
-  public function __construct(EntityManagerInterface $entity_manager, Messenger $messenger, AccountProxyInterface $current_user, TimeInterface $time) {
+  public function __construct(EntityRepositoryInterface $entity_repository, Messenger $messenger, AccountProxyInterface $current_user, TimeInterface $time) {
     $this->messenger = $messenger;
     $this->currentUser = $current_user;
     $this->time = $time;
-    parent::__construct($entity_manager);
+    parent::__construct($entity_repository);
   }
 
   /**
@@ -53,8 +53,8 @@ class EventInstanceForm extends ContentEntityForm {
    * Construct an EventInstanceForm.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
diff --git a/src/Form/EventSeriesDeleteForm.php b/src/Form/EventSeriesDeleteForm.php
index 5eab9ece..46d7ca4f 100644
--- a/src/Form/EventSeriesDeleteForm.php
+++ b/src/Form/EventSeriesDeleteForm.php
@@ -5,7 +5,7 @@ namespace Drupal\recurring_events\Form;
 use Drupal\Core\Entity\ContentEntityDeleteForm;
 use Drupal\Core\Form\FormStateInterface;
 use Symfony\Component\DependencyInjection\ContainerInterface;
-use Drupal\Core\Entity\EntityManagerInterface;
+use Drupal\Core\Entity\EntityRepositoryInterface;
 use Drupal\Core\Url;
 use Drupal\Core\Config\ConfigFactory;
 use Drupal\Core\Messenger\Messenger;
@@ -51,7 +51,7 @@ class EventSeriesDeleteForm extends ContentEntityDeleteForm {
    */
   public static function create(ContainerInterface $container) {
     return new static(
-      $container->get('entity.manager'),
+      $container->get('entity.repository'),
       $container->get('messenger'),
       $container->get('renderer'),
       $container->get('config.factory')
@@ -61,8 +61,8 @@ class EventSeriesDeleteForm extends ContentEntityDeleteForm {
   /**
    * Construct an EventSeriesDeleteForm.
    *
    * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
    *   The entity manager service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
    * @param \Drupal\Core\Render\Renderer $renderer
@@ -70,11 +70,11 @@ class EventSeriesDeleteForm extends ContentEntityDeleteForm {
    * @param \Drupal\Core\Config\ConfigFactory $config
    *   The config factory service.
    */
-  public function __construct(EntityManagerInterface $entity_manager, Messenger $messenger, Renderer $renderer, ConfigFactory $config) {
+  public function __construct(EntityRepositoryInterface $entity_repository, Messenger $messenger, Renderer $renderer, ConfigFactory $config) {
     $this->messenger = $messenger;
     $this->renderer = $renderer;
     $this->config = $config;
-    parent::__construct($entity_manager);
+    parent::__construct($entity_repository);
   }
 
   /**
@@ -61,8 +61,8 @@ class EventSeriesDeleteForm extends ContentEntityDeleteForm {
    * Construct an EventSeriesDeleteForm.
    *
-   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
-   *   The entity manager service.
+   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
+   *   The entity repository service.
    * @param \Drupal\Core\Messenger\Messenger $messenger
    *   The messenger service.
-- 
GitLab